proto/opentelemetry_proto_dart library

OpenTelemetry Protocol Buffer definitions for Dart

This file exports all the generated protobuf classes for OpenTelemetry.

Classes

AggregationTemporality
AggregationTemporality defines how a metric aggregator reports aggregated values. It describes how those values relate to the time interval over which they are aggregated.
AnyValue
AnyValue is used to represent any type of attribute value. AnyValue may contain a primitive value such as a string or integer or it may contain an arbitrary nested object containing arrays, key-value lists and primitives.
ArrayValue
ArrayValue is a list of AnyValue messages. We need ArrayValue as a message since oneof in AnyValue does not allow repeated fields.
DataPointFlags
DataPointFlags is defined as a protobuf 'uint32' type and is to be used as a bit-field representing 32 distinct boolean flags. Each flag defined in this enum is a bit-mask. To test the presence of a single flag in the flags of a data point, for example, use an expression like:
Exemplar
A representation of an exemplar, which is a sample input measurement. Exemplars also hold information about the environment when the measurement was recorded, for example the span and trace ID of the active span when the exemplar was recorded.
ExponentialHistogram
ExponentialHistogram represents the type of a metric that is calculated by aggregating as a ExponentialHistogram of all reported double measurements over a time interval.
ExponentialHistogramDataPoint
ExponentialHistogramDataPoint is a single data point in a timeseries that describes the time-varying values of a ExponentialHistogram of double values. A ExponentialHistogram contains summary statistics for a population of values, it may optionally contain the distribution of those values across a set of buckets.
ExponentialHistogramDataPoint_Buckets
Buckets are a set of bucket counts, encoded in a contiguous array of counts.
ExportLogsPartialSuccess
ExportLogsServiceRequest
ExportLogsServiceResponse
ExportMetricsPartialSuccess
ExportMetricsServiceRequest
ExportMetricsServiceResponse
ExportTracePartialSuccess
ExportTraceServiceRequest
ExportTraceServiceResponse
Gauge
Gauge represents the type of a scalar metric that always exports the "current value" for every data point. It should be used for an "unknown" aggregation.
Histogram
Histogram represents the type of a metric that is calculated by aggregating as a Histogram of all reported measurements over a time interval.
HistogramDataPoint
HistogramDataPoint is a single data point in a timeseries that describes the time-varying values of a Histogram. A Histogram contains summary statistics for a population of values, it may optionally contain the distribution of those values across a set of buckets.
InstrumentationScope
InstrumentationScope is a message representing the instrumentation scope information such as the fully qualified name and version.
KeyValue
KeyValue is a key-value pair that is used to store Span attributes, Link attributes, etc.
KeyValueList
KeyValueList is a list of KeyValue messages. We need KeyValueList as a message since oneof in AnyValue does not allow repeated fields. Everywhere else where we need a list of KeyValue messages (e.g. in Span) we use repeated KeyValue directly to avoid unnecessary extra wrapping (which slows down the protocol). The 2 approaches are semantically equivalent.
LogRecord
A log record according to OpenTelemetry Log Data Model: https://github.com/open-telemetry/oteps/blob/main/text/logs/0097-log-data-model.md
LogRecordFlags
LogRecordFlags represents constants used to interpret the LogRecord.flags field, which is protobuf 'fixed32' type and is to be used as bit-fields. Each non-zero value defined in this enum is a bit-mask. To extract the bit-field, for example, use an expression like:
LogsData
LogsData represents the logs data that can be stored in a persistent storage, OR can be embedded by other protocols that transfer OTLP logs data but do not implement the OTLP protocol.
LogsServiceBase
LogsServiceClient
Service that can be used to push logs between one Application instrumented with OpenTelemetry and an collector, or between an collector and a central collector (in this case logs are sent/received to/from multiple Applications).
Metric
Defines a Metric which has one or more timeseries. The following is a brief summary of the Metric data model. For more details, see:
MetricsData
MetricsData represents the metrics data that can be stored in a persistent storage, OR can be embedded by other protocols that transfer OTLP metrics data but do not implement the OTLP protocol.
MetricsServiceBase
MetricsServiceClient
Service that can be used to push metrics between one Application instrumented with OpenTelemetry and a collector, or between a collector and a central collector.
NumberDataPoint
NumberDataPoint is a single data point in a timeseries that describes the time-varying scalar value of a metric.
Resource
Resource information.
ResourceLogs
A collection of ScopeLogs from a Resource.
ResourceMetrics
A collection of ScopeMetrics from a Resource.
ResourceSpans
A collection of ScopeSpans from a Resource.
ScopeLogs
A collection of Logs produced by a Scope.
ScopeMetrics
A collection of Metrics produced by an Scope.
ScopeSpans
A collection of Spans produced by an InstrumentationScope.
SeverityNumber
Possible values for LogRecord.SeverityNumber.
Span
A Span represents a single operation performed by a single component of the system.
Span_Event
Event is a time-stamped annotation of the span, consisting of user-supplied text description and key-value pairs.
A pointer from the current span to another span in the same trace or in a different trace. For example, this can be used in batching operations, where a single batch handler processes multiple requests from different traces or when the handler receives a request from a different project.
Span_SpanKind
SpanKind is the type of span. Can be used to specify additional relationships between spans in addition to a parent/child relationship.
SpanFlags
SpanFlags represents constants used to interpret the Span.flags field, which is protobuf 'fixed32' type and is to be used as bit-fields. Each non-zero value defined in this enum is a bit-mask. To extract the bit-field, for example, use an expression like:
Status
The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs.
Status_StatusCode
For the semantics of status codes see https://github.com/open-telemetry/opentelemetry-specification/blob/main/specification/trace/api.md#set-status
Sum
Sum represents the type of a scalar metric that is calculated as a sum of all reported measurements over a time interval.
Summary
Summary metric data are used to convey quantile summaries, a Prometheus (see: https://prometheus.io/docs/concepts/metric_types/#summary) and OpenMetrics (see: https://github.com/OpenObservability/OpenMetrics/blob/4dbf6075567ab43296eed941037c12951faafb92/protos/prometheus.proto#L45) data type. These data points cannot always be merged in a meaningful way. While they can be useful in some applications, histogram data points are recommended for new applications.
SummaryDataPoint
SummaryDataPoint is a single data point in a timeseries that describes the time-varying values of a Summary metric.
SummaryDataPoint_ValueAtQuantile
Represents the value at a given quantile of a distribution.
TracesData
TracesData represents the traces data that can be stored in a persistent storage, OR can be embedded by other protocols that transfer OTLP traces data but do not implement the OTLP protocol.
TraceServiceBase
TraceServiceClient
Service that can be used to push spans between one Application instrumented with OpenTelemetry and a collector, or between a collector and a central collector (in this case spans are sent/received to/from multiple Applications).

Extensions

GeneratedMessageGenericExtensions on T
Extensions on GeneratedMessages.

Constants

AggregationTemporality$json → const Map<String, Object>
AnyValue$json → const Map<String, Object>
ArrayValue$json → const Map<String, Object>
DataPointFlags$json → const Map<String, Object>
Exemplar$json → const Map<String, Object>
ExponentialHistogram$json → const Map<String, Object>
ExponentialHistogramDataPoint$json → const Map<String, Object>
ExponentialHistogramDataPoint_Buckets$json → const Map<String, Object>
ExportLogsPartialSuccess$json → const Map<String, Object>
ExportLogsServiceRequest$json → const Map<String, Object>
ExportLogsServiceResponse$json → const Map<String, Object>
ExportMetricsPartialSuccess$json → const Map<String, Object>
ExportMetricsServiceRequest$json → const Map<String, Object>
ExportMetricsServiceResponse$json → const Map<String, Object>
ExportTracePartialSuccess$json → const Map<String, Object>
ExportTraceServiceRequest$json → const Map<String, Object>
ExportTraceServiceResponse$json → const Map<String, Object>
Gauge$json → const Map<String, Object>
Histogram$json → const Map<String, Object>
HistogramDataPoint$json → const Map<String, Object>
InstrumentationScope$json → const Map<String, Object>
KeyValue$json → const Map<String, Object>
KeyValueList$json → const Map<String, Object>
LogRecord$json → const Map<String, Object>
LogRecordFlags$json → const Map<String, Object>
LogsData$json → const Map<String, Object>
Metric$json → const Map<String, Object>
MetricsData$json → const Map<String, Object>
NumberDataPoint$json → const Map<String, Object>
Resource$json → const Map<String, Object>
ResourceLogs$json → const Map<String, Object>
ResourceMetrics$json → const Map<String, Object>
ResourceSpans$json → const Map<String, Object>
ScopeLogs$json → const Map<String, Object>
ScopeMetrics$json → const Map<String, Object>
ScopeSpans$json → const Map<String, Object>
SeverityNumber$json → const Map<String, Object>
Span$json → const Map<String, Object>
Span_Event$json → const Map<String, Object>
Span_Link$json → const Map<String, Object>
Span_SpanKind$json → const Map<String, Object>
SpanFlags$json → const Map<String, Object>
Status$json → const Map<String, Object>
Status_StatusCode$json → const Map<String, Object>
Sum$json → const Map<String, Object>
Summary$json → const Map<String, Object>
SummaryDataPoint$json → const Map<String, Object>
SummaryDataPoint_ValueAtQuantile$json → const Map<String, Object>
TracesData$json → const Map<String, Object>

Properties

aggregationTemporalityDescriptor Uint8List
Descriptor for AggregationTemporality. Decode as a google.protobuf.EnumDescriptorProto.
final
anyValueDescriptor Uint8List
Descriptor for AnyValue. Decode as a google.protobuf.DescriptorProto.
final
arrayValueDescriptor Uint8List
Descriptor for ArrayValue. Decode as a google.protobuf.DescriptorProto.
final
dataPointFlagsDescriptor Uint8List
Descriptor for DataPointFlags. Decode as a google.protobuf.EnumDescriptorProto.
final
exemplarDescriptor Uint8List
Descriptor for Exemplar. Decode as a google.protobuf.DescriptorProto.
final
exponentialHistogramDataPointDescriptor Uint8List
Descriptor for ExponentialHistogramDataPoint. Decode as a google.protobuf.DescriptorProto.
final
exponentialHistogramDescriptor Uint8List
Descriptor for ExponentialHistogram. Decode as a google.protobuf.DescriptorProto.
final
exportLogsPartialSuccessDescriptor Uint8List
Descriptor for ExportLogsPartialSuccess. Decode as a google.protobuf.DescriptorProto.
final
exportLogsServiceRequestDescriptor Uint8List
Descriptor for ExportLogsServiceRequest. Decode as a google.protobuf.DescriptorProto.
final
exportLogsServiceResponseDescriptor Uint8List
Descriptor for ExportLogsServiceResponse. Decode as a google.protobuf.DescriptorProto.
final
exportMetricsPartialSuccessDescriptor Uint8List
Descriptor for ExportMetricsPartialSuccess. Decode as a google.protobuf.DescriptorProto.
final
exportMetricsServiceRequestDescriptor Uint8List
Descriptor for ExportMetricsServiceRequest. Decode as a google.protobuf.DescriptorProto.
final
exportMetricsServiceResponseDescriptor Uint8List
Descriptor for ExportMetricsServiceResponse. Decode as a google.protobuf.DescriptorProto.
final
exportTracePartialSuccessDescriptor Uint8List
Descriptor for ExportTracePartialSuccess. Decode as a google.protobuf.DescriptorProto.
final
exportTraceServiceRequestDescriptor Uint8List
Descriptor for ExportTraceServiceRequest. Decode as a google.protobuf.DescriptorProto.
final
exportTraceServiceResponseDescriptor Uint8List
Descriptor for ExportTraceServiceResponse. Decode as a google.protobuf.DescriptorProto.
final
gaugeDescriptor Uint8List
Descriptor for Gauge. Decode as a google.protobuf.DescriptorProto.
final
histogramDataPointDescriptor Uint8List
Descriptor for HistogramDataPoint. Decode as a google.protobuf.DescriptorProto.
final
histogramDescriptor Uint8List
Descriptor for Histogram. Decode as a google.protobuf.DescriptorProto.
final
instrumentationScopeDescriptor Uint8List
Descriptor for InstrumentationScope. Decode as a google.protobuf.DescriptorProto.
final
keyValueDescriptor Uint8List
Descriptor for KeyValue. Decode as a google.protobuf.DescriptorProto.
final
keyValueListDescriptor Uint8List
Descriptor for KeyValueList. Decode as a google.protobuf.DescriptorProto.
final
logRecordDescriptor Uint8List
Descriptor for LogRecord. Decode as a google.protobuf.DescriptorProto.
final
logRecordFlagsDescriptor Uint8List
Descriptor for LogRecordFlags. Decode as a google.protobuf.EnumDescriptorProto.
final
logsDataDescriptor Uint8List
Descriptor for LogsData. Decode as a google.protobuf.DescriptorProto.
final
metricDescriptor Uint8List
Descriptor for Metric. Decode as a google.protobuf.DescriptorProto.
final
metricsDataDescriptor Uint8List
Descriptor for MetricsData. Decode as a google.protobuf.DescriptorProto.
final
numberDataPointDescriptor Uint8List
Descriptor for NumberDataPoint. Decode as a google.protobuf.DescriptorProto.
final
resourceDescriptor Uint8List
Descriptor for Resource. Decode as a google.protobuf.DescriptorProto.
final
resourceLogsDescriptor Uint8List
Descriptor for ResourceLogs. Decode as a google.protobuf.DescriptorProto.
final
resourceMetricsDescriptor Uint8List
Descriptor for ResourceMetrics. Decode as a google.protobuf.DescriptorProto.
final
resourceSpansDescriptor Uint8List
Descriptor for ResourceSpans. Decode as a google.protobuf.DescriptorProto.
final
scopeLogsDescriptor Uint8List
Descriptor for ScopeLogs. Decode as a google.protobuf.DescriptorProto.
final
scopeMetricsDescriptor Uint8List
Descriptor for ScopeMetrics. Decode as a google.protobuf.DescriptorProto.
final
scopeSpansDescriptor Uint8List
Descriptor for ScopeSpans. Decode as a google.protobuf.DescriptorProto.
final
severityNumberDescriptor Uint8List
Descriptor for SeverityNumber. Decode as a google.protobuf.EnumDescriptorProto.
final
spanDescriptor Uint8List
Descriptor for Span. Decode as a google.protobuf.DescriptorProto.
final
spanFlagsDescriptor Uint8List
Descriptor for SpanFlags. Decode as a google.protobuf.EnumDescriptorProto.
final
statusDescriptor Uint8List
Descriptor for Status. Decode as a google.protobuf.DescriptorProto.
final
sumDescriptor Uint8List
Descriptor for Sum. Decode as a google.protobuf.DescriptorProto.
final
summaryDataPointDescriptor Uint8List
Descriptor for SummaryDataPoint. Decode as a google.protobuf.DescriptorProto.
final
summaryDescriptor Uint8List
Descriptor for Summary. Decode as a google.protobuf.DescriptorProto.
final
tracesDataDescriptor Uint8List
Descriptor for TracesData. Decode as a google.protobuf.DescriptorProto.
final