traceId property
A unique identifier of a trace that this linked span is part of. The ID is a 16-byte array.
Implementation
@$pb.TagNumber(1)
$core.List<$core.int> get traceId => $_getN(0);
A unique identifier of a trace that this linked span is part of. The ID is a 16-byte array.
@$pb.TagNumber(1)
$core.List<$core.int> get traceId => $_getN(0);