forceFlush method

  1. @override
Future<void> forceFlush()
override

Forces the exporter to flush any pending log records.

This method is a hint to ensure export of any log records the exporter received before this call. Should be completed ASAP.

Implementation

@override
Future<void> forceFlush() async {}